@@ -15,11 +15,11 @@ Siebel::Srvrmgr::Daemon::ActionStash - singleton to stash data returned by Siebe
     extends 'Siebel::Srvrmgr::Daemon::Action';
 
     my $stash = Siebel::Srvrmgr::Daemon::ActionStash->instance();
-	$stash->set_stash([{foobar => foobar}, [qw(one two three)]]);
+    $stash->set_stash([{foobar => foobar}, [qw(one two three)]]);
 
     package main;
 
-	my $stash = Siebel::Srvrmgr::Daemon::ActionStash->instance();
+    my $stash = Siebel::Srvrmgr::Daemon::ActionStash->instance();
 
     # do something with the get_stash method
 
@@ -39,10 +39,7 @@ Considering this situation, the interface of this class should be considered exp
 
 =cut
 
-use warnings;
-use strict;
 use MooseX::Singleton;
-use MooseX::FollowPBP;
 
 =pod
 
@@ -50,19 +47,19 @@ use MooseX::FollowPBP;
 
 =head2 stash
 
-This attribute is a reference to some data. This means that it will accept B<any> reference to some that structure that you think it will be useful.
+This attribute is a array reference of references. This means that it will accept B<any> reference to some data structure that you think it will be 
+useful (including objects).
 
 If undefined, this attribute will returned an empty array reference.
 
 =cut
 
 has stash => (
-    is => 'rw',
-
-# :TODO      :09/05/2013 16:42:51:: use array references to push any reference, should create set_stash to allow that to work
-#    isa      => 'ArrayRef[Ref]',
-    isa      => 'Ref',
+    is       => 'rw',
+    isa      => 'ArrayRef[Ref]',
     required => 0,
+    reader   => 'get_stash',
+    writer   => 'set_stash',
     default  => sub { return [] }
 );
 
@@ -72,15 +69,65 @@ has stash => (
 
 =head2 get_stash
 
-Returns the C<stash> attribute reference.
+Returns the C<stash> attribute array reference.
 
 =head2 set_stash
 
-Sets the C<stash> attribute. Expects a reference as parameter.
+Sets the C<stash> attribute. Expects an array reference as parameter.
+
+Beware that such call will complete remove all other data stored in the stash. To add single items, see C<push_stash> method.
+
+=head2 push_stash
+
+Expects as parameter a reference.
+
+Pushes a new reference into the C<stash> attribute.
+
+If there is no member in the C<stash> attribute, the method C<set_stash> will be invoked to set the attribute.
+
+=cut
+
+sub push_stash {
+
+    my $self = shift;
+    my $ref  = shift;
+
+    my $array_ref = $self->get_stash;
+
+    if ( scalar( @{$array_ref} ) > 0 ) {
+
+        push( @{$array_ref}, $ref );
+
+    }
+    else {
+
+        $self->set_stash( [$ref] );
+
+    }
+
+    return 1;
+
+}
+
+=head2 shift_stash
+
+Shifts the C<stash> attribute, removing the first item in the attribute and returning it.
+
+If there is not other member to be shift, it will return undef.
+
+=cut
+
+sub shift_stash {
+
+    my $self = shift;
+
+    return shift( @{ $self->get_stash() } );
+
+}
 
 =head1 SEE ALSO
 
-=over 2
+=over
 
 =item *
 
@@ -94,11 +141,11 @@ L<MooseX::Singleton>
 
 =head1 AUTHOR
 
-Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>.
 
 This file is part of Siebel Monitoring Tools.
 
@@ -113,7 +160,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with Siebel Monitoring Tools.  If not, see <http://www.gnu.org/licenses/>.
+along with Siebel Monitoring Tools.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
 
