@@ -75,8 +75,6 @@ sub new {
 
     my $logger = Log::Log4perl->get_logger('Siebel::Srvrmgr::ListParser');
 
-    weaken($logger);
-
     $logger->logdie('the output type mapping reference received is not valid')
       unless ( ( defined($map_ref) ) and ( ref($map_ref) eq 'HASH' ) );
 
@@ -86,6 +84,7 @@ sub new {
             my $self = shift;
 
             my $curr_line = shift( @{ $self->notes('all_data') } );
+ # :TODO:22-02-2015 18:22:29:: add a new method to do that
             $self->notes( 'line_num' => ( $self->notes('line_num') + 1 ) );
 
             if ( defined($curr_line) ) {
@@ -105,7 +104,7 @@ sub new {
                 }
 
             }
-            else {
+            else { # no more lines to process
 
                 return 1;
 
@@ -119,6 +118,9 @@ sub new {
         no_data => {
             do => sub {
 
+                my $logger =
+                  Log::Log4perl->get_logger('Siebel::Srvrmgr::ListParser');
+
                 if ( $logger->is_debug() ) {
 
                     $logger->debug('Searching for useful data');
@@ -160,7 +162,6 @@ sub new {
                     }
 
                 },
-                no_data => sub { return 1 }
             ],
             message => 'Line read'
 
@@ -188,16 +189,21 @@ sub new {
                     return ( $state->notes('line') =~ SRVRMGR_PROMPT );
 
                 },
-                greetings => sub { return 1 }
             ],
             message => 'prompt found'
         },
         end => {
-            do    => sub { $logger->debug('Enterprise says bye-bye') },
+            do => sub {
+
+                my $logger =
+                  Log::Log4perl->get_logger('Siebel::Srvrmgr::ListParser');
+                $logger->debug('Enterprise says bye-bye');
+
+            },
             rules => [
                 no_data => sub {
                     return 1;
-                  }
+                }
             ],
             message => 'EOF'
         },
@@ -221,7 +227,6 @@ sub new {
                     return ( $state->notes('line') =~ SRVRMGR_PROMPT );
 
                 },
-                list_comp => sub { return 1; }
             ],
             message => 'prompt found'
         },
@@ -245,7 +250,6 @@ sub new {
                     return ( $state->notes('line') =~ SRVRMGR_PROMPT );
 
                 },
-                list_comp_types => sub { return 1; }
             ],
             message => 'prompt found'
         },
@@ -269,7 +273,6 @@ sub new {
                     return ( $state->notes('line') =~ SRVRMGR_PROMPT );
 
                 },
-                list_params => sub { return 1; }
             ],
             message => 'prompt found'
         },
@@ -293,7 +296,6 @@ sub new {
                     return ( $state->notes('line') =~ SRVRMGR_PROMPT );
 
                 },
-                list_comp_def => sub { return 1; }
             ],
             message => 'prompt found'
         },
@@ -317,7 +319,6 @@ sub new {
                     return ( $state->notes('line') =~ SRVRMGR_PROMPT );
 
                 },
-                list_tasks => sub { return 1; }
             ],
             message => 'prompt found'
         },
@@ -341,7 +342,6 @@ sub new {
                     return ( $state->notes('line') =~ SRVRMGR_PROMPT );
 
                 },
-                list_servers => sub { return 1; }
             ],
             message => 'prompt found'
         },
@@ -365,7 +365,29 @@ sub new {
                     return ( $state->notes('line') =~ SRVRMGR_PROMPT );
 
                 },
-                list_sessions => sub { return 1; }
+            ],
+            message => 'prompt found'
+        },
+        set_delimiter => {
+            label    => 'parses output (?) from set delimiter command',
+            on_enter => sub {
+                my $state = shift;
+                $state->notes( is_cmd_changed => 0 );
+                $state->notes( is_data_wanted => 1 );
+            },
+            on_exit => sub {
+
+                my $state = shift;
+                $state->notes( is_data_wanted => 0 );
+
+            },
+            rules => [
+                command_submission => sub {
+
+                    my $state = shift;
+                    return ( $state->notes('line') =~ SRVRMGR_PROMPT );
+
+                },
             ],
             message => 'prompt found'
         },
@@ -389,7 +411,6 @@ sub new {
                     return ( $state->notes('line') =~ SRVRMGR_PROMPT );
 
                 },
-                load_preferences => sub { return 1; }
             ],
             message => 'prompt found'
         },
@@ -398,6 +419,8 @@ sub new {
 
                 my $state = shift;
 
+                my $logger =
+                  Log::Log4perl->get_logger('Siebel::Srvrmgr::ListParser');
                 if ( $logger->is_debug() ) {
 
                     $logger->debug( 'command_submission got ['
@@ -439,6 +462,24 @@ sub new {
 
             },
             rules => [
+                set_delimiter => sub {
+
+                    my $state = shift;
+
+                    if ( $state->notes('last_command') =~
+                        $map_ref->{set_delimiter} )
+                    {
+
+                        return 1;
+
+                    }
+                    else {
+
+                        return 0;
+
+                    }
+
+                },
                 list_comp => sub {
 
                     my $state = shift;
@@ -599,15 +640,7 @@ sub new {
                     }
 
                 },
-
                 # add other possibilities here of list commands
-                command_submission => sub {
-                    $logger->warn(
-"Possible invalid state due incapability to define the state change (output class)"
-                    );
-                    return 1;
-                  }    # this must be the last item
-
             ],
             message => 'command submitted'
         }
@@ -617,51 +650,6 @@ sub new {
 
 }
 
-=pod
-
-=head2 free_refs
-
-This methods eliminates all circular references that version 0.31 of L<FSA::Rules> has, which makes it impossible to call the C<DESTROY>
-before the program termination.
-
-It should be invoked before program termination, possibly also in C<DESTROY> and C<DEMOLISH> methods of objects to give to the Perl interpreter a change
-to release memory by calling the related C<DESTROY> methods of L<FSA::Rules> and L<FSA::State> instances.
-
-=cut
-
-sub free_refs {
-
-    my $self = shift;
-
-    my $machines = \%FSA::Rules::machines;
-
-    foreach my $state ( keys %{ $machines->{$self}->{table} } ) {
-
-        $machines->{$self}->{table}->{$state} = undef;
-        delete $machines->{$self}->{table}->{$state};
-
-    }
-
-    $self->{done} = undef;
-    $machines->{$self}->{self} = undef;
-
-    my $all_states = \%FSA::Rules::states;
-
-    foreach my $state ( @{ $self->states } ) {
-
-        $all_states->{$state}->{machine} = undef;
-        delete $all_states->{$state}->{machine};
-
-        for ( my $i = 0 ; $i <= $#{ $all_states->{$state}->{rules} } ; $i++ ) {
-
-            $all_states->{$state}->{rules}->[$i]->{state} = undef;
-
-        }
-
-    }
-
-}
-
 1;
 
 =pod
